<?php
/**
 * TP Philosophy Pro Testimonial section customizer options
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

// Add testimonial section
$wp_customize->add_section( 'tp_philosophy_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','tp-philosophy-pro' ),
	'description'       => esc_html__( 'Testimonial section options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_homepage_sections_panel'
) );

// Add testimonial section enable setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[testimonial_enable]', array(
	'default'           => $options['testimonial_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[testimonial_enable]', array(
	'label'             => esc_html__( 'Enable on', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_testimonial_section',
	'type'              => 'select',
	'choices'           => tp_philosophy_pro_enable_disable_options()
) );

if ( ! class_exists( 'TP_Philosophy_Tools' ) ) {
    $content_type_description = esc_html__( 'Testimonial section requires', 'tp-philosophy-pro' ) . sprintf( '<a target="_blank" href="%s"> %s </a>', esc_url( 'https://wordpress.org/plugins/tp-philosophy-teams/' ), esc_html__( 'TP Philosophy Tools Plugin', 'tp-philosophy-pro' ) );

	$choices = array(
		'demo'     => esc_html__( 'Demo', 'tp-philosophy-pro' ),
		'posts'    => esc_html__( 'Posts', 'tp-philosophy-pro' ),
		'page'     => esc_html__( 'Page', 'tp-philosophy-pro' ),
		'category' => esc_html__( 'Category', 'tp-philosophy-pro' ),
	);
} else{
    $content_type_description = '';
    $choices = array(
		'demo'                      => esc_html__( 'Demo', 'tp-philosophy-pro' ),
		'posts'                     => esc_html__( 'Posts', 'tp-philosophy-pro' ),
		'page'                      => esc_html__( 'Page', 'tp-philosophy-pro' ),
		'category'                  => esc_html__( 'Category', 'tp-philosophy-pro' ),
		'tp-philosophy-testimonial' => esc_html__( 'Tp Testimonial', 'tp-philosophy-pro' ),
	);
}

// Add testimonial section content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[testimonial_content_type]', array(
	'default'           => $options['testimonial_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[testimonial_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'description' 		=> $content_type_description,
	'section'         	=> 'tp_philosophy_pro_testimonial_section',
	'type'            	=> 'select',
	'choices'         	=> $choices,
	'active_callback' 	=> 'tp_philosophy_pro_is_testimonial_enable',
) );

// Add testimonial section number of posts setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[testimonial_no_of_slides]', array(
	'default'           => $options['testimonial_no_of_slides'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[testimonial_no_of_slides]', array(
	'label'           	=> esc_html__( 'Number Of Testimonials', 'tp-philosophy-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects. Max value is 5', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_testimonial_section',
	'type'            	=> 'number',
	'input_attrs'		=> array(
		'min'			=> '1',
		'max'			=> '5',
		'step'			=> '1',
		'style'			=> 'width:50px',
	),
	'active_callback' 	=> 'tp_philosophy_pro_is_testimonial_demo_inactive',
) );

$testimonial_no_of_slides = $options['testimonial_no_of_slides']; 

for ( $i=1; $i<=$testimonial_no_of_slides ; $i++) { 


	// Add setting and controls to input page id
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[testimonial_page_id_'. $i .']', array(
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[testimonial_page_id_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Testimonial Page #%s' , 'tp-philosophy-pro' ), $i ),
		'section'           => 'tp_philosophy_pro_testimonial_section',
		'type'              => 'dropdown-pages',
		'active_callback'	=> 'tp_philosophy_pro_is_testimonial_content_page_active',
	) );
}

// Add setting and controls to input post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[testimonial_post_ids]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[testimonial_post_ids]', array(
	'label'           => esc_html__( 'Testimonial ID', 'tp-philosophy-pro' ),
	'description' 	  => esc_html__( 'Enter post ID seperated with comma. Example 88,91,93', 'tp-philosophy-pro' ),
	'section'         => 'tp_philosophy_pro_testimonial_section',
	'active_callback' => 'tp_philosophy_pro_is_testimonial_content_post_active',
) );

// Add setting and controls to input cpt post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[cpt_testimonial_post_ids]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[cpt_testimonial_post_ids]', array(
	'label'           => esc_html__( 'CPT Testimonial', 'tp-philosophy-pro' ),
	'description' 	  => esc_html__( 'Enter post ID seperated with comma. Example 88,91,93', 'tp-philosophy-pro' ),

	'section'         => 'tp_philosophy_pro_testimonial_section',
	'active_callback' => 'tp_philosophy_pro_is_cpt_testimonial_content_post_active',
) );

// Add Category Content Type
$wp_customize->add_setting(  'tp_philosophy_pro_theme_options[testimonial_content_category]', array(
  	'sanitize_callback' => 'tp_philosophy_pro_sanitize_dropdown_category_list',
) ) ;

$wp_customize->add_control( new Tp_Philosophy_Pro_Dropdown_Category_Control ( $wp_customize,'tp_philosophy_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_testimonial_section',
	'active_callback'   => 'tp_philosophy_pro_is_testimonial_category_active'
) ) );


/**
 * Background Image
 */

// Add Background control options heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[testimonial_background_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[testimonial_background_heading]', array(
	'label'           	=> esc_html__( 'Background Image', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_testimonial_section',
	'type'				=> 'description',
	'active_callback' 	=> 'tp_philosophy_pro_is_testimonial_demo_inactive',
) ) );


// Add services background image setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[testimonial_background_image]', array(
	'default'           => $options['testimonial_background_image'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tp_philosophy_pro_theme_options[testimonial_background_image]',
    array(
		'label'           => esc_html__( 'Upload Services Background Image', 'tp-philosophy-pro' ),
		'description'     => esc_html__( 'Recommended slide image size is 862x722 px', 'tp-philosophy-pro' ),
		'section'         => 'tp_philosophy_pro_testimonial_section',
		'active_callback' => 'tp_philosophy_pro_is_testimonial_demo_inactive',
   )
) );