<?php
/**
 * Slider section
 *
 * This is the template for the content of Slider section
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */
if ( ! function_exists( 'tp_philosophy_pro_add_slider_section' ) ) :
    /**
     * Add Slider section
     *
     * @since 1.0
     */
    function tp_philosophy_pro_add_slider_section() {
        // Check if Slider is enabled on frontpage
        $slider_enable = apply_filters( 'tp_philosophy_pro_section_status', true, 'slider_enable' );

        if ( true !== $slider_enable ) {
          return false;
        }

        // Get Slider section details
        $section_details = array();
        $section_details = apply_filters( 'tp_philosophy_pro_filter_slider_details', $section_details );

        if ( empty( $section_details ) ) {
          return;
        }

        // Render Slider section now.
        tp_philosophy_pro_render_slider_section( $section_details );
    }
endif;
add_action( 'tp_philosophy_pro_homepage_section', 'tp_philosophy_pro_add_slider_section', 10 );


if ( ! function_exists( 'tp_philosophy_pro_get_slider_section_details' ) ) :
    /**
     * Slider section details.
     *
     * @since 1.0
     * @param array $input Slider section details.
     */
    function tp_philosophy_pro_get_slider_section_details( $input ) {
        $options = tp_philosophy_pro_get_theme_options();

        // Slider type
        $slider_content_type = $options['slider_content_type'];
        $no_of_slides        = ! empty( $options['slider_no_of_slides'] ) ? $options['slider_no_of_slides'] : 3;
        $read_more_text      = ! empty( $options['slide_learn_more_text'] ) ? $options['slide_learn_more_text'] : '';

        $content = array();
        switch ( $slider_content_type ) {
            case 'demo':
                $demo_title = array(
                    '<h1>'. esc_html__( 'Let&rsquo;s Build', 'tp-philosophy-pro' ) .'</h1><h2>'. esc_html__( 'something great', 'tp-philosophy-pro' ) .'</h2><h2 class="sub-title">'. esc_html__( 'Together', 'tp-philosophy-pro' ). '</h2>'
                        ,
                    '<h1>'. esc_html__( 'We are', 'tp-philosophy-pro' ) .'</h1><h2>'. esc_html__( 'Good at', 'tp-philosophy-pro' ) .'</h2><h2 class="sub-title">'. esc_html__( 'What we do', 'tp-philosophy-pro' ). '</h2>',

                );

                $image_array = array( 'banner.jpg', 'banner.jpg' );

                for ( $i = 0; $i < 2; $i++ ) {
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/'. $image_array[$i];
                    $content[$i]['title']        = $demo_title[$i];
                    $content[$i]['link_text']    = esc_html__( 'get started', 'tp-philosophy-pro' );
                    $content[$i]['url']          = '#';
                }
            break;

            case 'posts':
                $posts_ids      = ! empty( $options['slider_posts_ids'] ) ? $options['slider_posts_ids'] : array();

                // Bail if no valid posts are selected.
                if ( empty( $posts_ids ) ) {
                    return $input;
                }

                $args = array(
                    'post_type'      => 'post',
                    'post__in'       => $posts_ids,
                    'orderby'        => 'post__in',
                    'posts_per_page' => absint( $no_of_slides ),
                );

                $posts = get_posts( $args ); // get posts 

                $i = 1;
                foreach ( $posts as $post ) {

                    $post_id   = $post->ID;
                    $img_array = null;

                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                    }

                    if ( isset( $img_array ) ) {
                      $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['url']        = get_permalink( $post_id );
                    $content[$i]['title']      = get_the_title( $post_id );
                    $content[$i]['link_text']  = $read_more_text;

                $i++;
                }
            break;

            case 'pages':
                $page_ids      = array(); // set empty array of pages id

                for( $i = 1; $i <= $no_of_slides; $i++ ){
                    if( !empty( $options['slider_page_id_'. $i ] ) ){
                        $post_id    = ! empty ( $options['slider_page_id_' . $i] ) ? absint( $options['slider_page_id_' . $i] ) : '';
                        $page_ids  = array_merge( $page_ids, array( $post_id ) );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $page_ids ) ) {
                    return $input;
                }

                $args = array(
                    'post_type'      => 'page',
                    'post__in'       => $page_ids,
                    'orderby'        => 'post__in',
                    'posts_per_page' => absint( $no_of_slides ),
                );

                $pages = get_posts( $args ); // get pages 

                $i = 1;
                foreach ( $pages as $page ) {

                    $page_id   = $page->ID;
                    $img_array = null;

                    if ( has_post_thumbnail( $page_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'full' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['url']        = get_permalink( $page_id );
                    $content[$i]['title']      = get_the_title( $page_id );
                    $content[$i]['link_text']  = $read_more_text;

                $i++;
                }
            break;

            case 'category':
                // Fetch posts.
                $category_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';

                if( empty( $category_id ) ){
                    return;
                }

                $args = array( 
                    'cat'                 => absint( $category_id ),
                    'posts_per_page'      => absint( $no_of_slides ),
                    'ignore_sticky_posts' => true
                );

                $category_posts = get_posts( $args );

                $i = 1;
                foreach( $category_posts as $category_post ){
                    $post_id   = $category_post->ID;
                    $img_array = array();

                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                    }  else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                    }   

                    $content[$i]['img_array']    = $img_array;
                    $content[$i]['url']        = get_permalink( $post_id );
                    $content[$i]['title']      = get_the_title( $post_id );
                    $content[$i]['link_text']  = $read_more_text;
                    
                    $i++;     
                }
            break;

            case 'custom':
                for( $i = 1; $i <= $no_of_slides; $i++ ){
                    $img_array = ! empty( $options['custom_slide_image_'. $i ] ) ? array( $options['custom_slide_image_'. $i ] ) : array('test');                
                    $title     = ! empty( $options['custom_slider_title_'. $i ] ) ? $options['custom_slider_title_'. $i ] : '';
                    $link_text =  !empty( $options['custom_slide_learn_more_text_'. $i ] ) ? $options['custom_slide_learn_more_text_'. $i ] : esc_html__( 'Get Started', 'tp-philosophy-pro' );
                    $link_url  = ! empty( $options['custom_slide_link_'. $i ] ) ? $options['custom_slide_link_'. $i ] : '#';

                    if( ! empty( $img_array ) ){
                        $content[$i]['img_array'] = $img_array;
                        $content[$i]['url']       = $link_url;
                        $content[$i]['title']     = $title;
                        $content[$i]['link_text'] = $link_text;
                    }
                }
            break;

            default:
            break;
        }
                                                                                                                   
        if ( !empty( $content ) ) {
          $input = $content;
        }

    return $input;
  }
endif;
// Slider section content details.
add_filter( 'tp_philosophy_pro_filter_slider_details', 'tp_philosophy_pro_get_slider_section_details' );


if ( ! function_exists( 'tp_philosophy_pro_render_slider_section' ) ) :
    /**
     * Start Slider section
     *
     * @return string Slider content
     * @since 1.0
     *
     */
    function tp_philosophy_pro_render_slider_section( $content_details ) {

        if ( empty( $content_details ) ) {
            return;
        }

        $options         = tp_philosophy_pro_get_theme_options(); // get theme options
        
        $content_type    = $options['slider_content_type'];
        $slider_effect   = ! empty( $options['slider_content_effect'] ) ? $options['slider_content_effect'] : 'cubic-bezier(0.250, 0.100, 0.250, 1.000)';
        $slider_control  = ( $options['enable_slider_controls'] == true ) ? 'true' : 'false';
        $slider_dragable = ( $options['enable_slider_dragable'] == true ) ? 'true' : 'false';
        $enable_pager    = ( $options['enable_slider_pager'] == true ) ? 'true' : 'false';
        $slider_pause    = ( $options['slider_pause_on_hover'] == true ) ? 'true' : 'false';
        $enable_slider_content = ( $options['enable_slider_content'] == true ) ? true : false;

        $slider_box_layout_class    = ( $options['slider_box_layout'] ) ? 'add-border' : 'false';
        
        $data_slick_value = '{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": '. esc_attr( $enable_pager ) .', "autoplay": true, "pauseOnHover":'. esc_attr( $slider_pause ).', "arrows": '. esc_attr( $slider_control ).', "draggable":'.esc_attr( $slider_dragable ).', "fade": false }';
    ?>
        <section id="main-slider" class="align-center main-featured-slider" data-effect="<?php echo esc_attr( $slider_effect ); ?>" data-slick=<?php echo "'" . $data_slick_value . "'"; ?>>
        <?php foreach ( $content_details as $content ) : ?>
            <div class="slider-item" style="background-image: url('<?php echo esc_url( $content['img_array'][0] ); ?>');">
                <?php if ( $enable_slider_content ) : ?>
                    <div class="main-slider-contents <?php echo esc_attr( $slider_box_layout_class ); ?> wrapper">
                        <?php 
                            $content_title = $content['title'];
                            if ( 'posts' == $content_type || 'pages' == $content_type || 'category' == $content_type ){
                                if ( ! empty( $content_title ) ){
                                    echo '<h1>'. esc_html( $content_title ) .'</h1>';
                                }
                            } else{
                                if( ! empty( $content_title ) ){
                                    echo wp_kses_post( $content['title'] );
                                }
                            }

                            $link_text = ! empty( $content['link_text'] ) ? $content['link_text'] : esc_html__( 'Get Started', 'tp-philosophy-pro' );
                            echo  '<a href="'. esc_url( $content['url'] ) .'" class="btn btn-fill">'. esc_html( $link_text ) .'</a>';
                        ?>
                    </div><!--.main-slider-->
                <?php endif; ?>
            </div><!-- .slider-item -->
        <?php endforeach; ?>
        </section><!-- #main-slider -->
    <?php 
    }
endif;